@@ -105,58 +105,24 @@ class _LogFormatter(logging.Formatter):
 
 #: settings for blog user
 settings = _Options()
-settings.source = 'content'
-settings.output = 'deploy'
-settings.static_output = '%s/static' % settings.output
-settings.static_prefix = '/static/'
-settings.theme = 'default'
-
-settings.permalink = '{{date.year}}/{{filename}}'
-settings.use_relative_url = False
-settings.perpage = 30
-settings.feedcount = 20
-settings.timezone = '+00:00'
-
-settings.site = {
-    'name': 'Felix Felicis',
-    'url': 'http://github.com',
-    'prefix': '',
-}
-
-settings.author = 'nickname'
-settings.authors = {}
-
-settings.readers = {
-    'markdown': 'liquidluck.readers.markdown.MarkdownReader',
-}
-settings.readers_variables = {}
-
-settings.writers = {
-    'post': 'liquidluck.writers.core.PostWriter',
-    'page': 'liquidluck.writers.core.PageWriter',
-    'archive': 'liquidluck.writers.core.ArchiveWriter',
-    'archive_feed': 'liquidluck.writers.core.ArchiveFeedWriter',
-    'file': 'liquidluck.writers.core.FileWriter',
-    'static': 'liquidluck.writers.core.StaticWriter',
-    'year': 'liquidluck.writers.core.YearWriter',
-    'tag': 'liquidluck.writers.core.TagWriter',
-    'category': 'liquidluck.writers.core.CategoryWriter',
-    'category_feed': 'liquidluck.writers.core.CategoryFeedWriter',
-}
-settings.writers_variables = {}
-settings.template_variables = {}
-settings.template_filters = {}
-settings.theme_variables = {}
+settings.site = {}
+settings.config = {}
+settings.author = {}
+settings.reader = {}
+settings.writer = {}
+settings.theme = {}
 
 
 #: settings for liquidluck
 g = _Options()
 g.detail_logging = False
 g.liquid_directory = os.path.abspath(os.path.dirname(__file__))
-g.source_directory = settings.source
-g.output_directory = settings.output
-g.static_directory = settings.static_output
-g.theme_directory = os.path.join(g.liquid_directory, '_themes', settings.theme)
+g.source_directory = 'source'
+g.output_directory = 'deploy'
+g.static_directory = 'static'
+g.theme_directory = os.path.join(
+    g.liquid_directory, '_themes', 'default'
+)
 g.resource = {}
 g.public_posts = []
 g.secure_posts = []
